@@ -121,7 +121,7 @@ void foo_group4(bar_group4&)
 
 int main(int argc, char* argv[])
 {
-  TestUtilities* util = TestUtilities::get_instance();
+  auto util = TestUtilities::get_instance();
 
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
@@ -140,7 +140,7 @@ int main(int argc, char* argv[])
 
   // Allocate on the heap. valgrind can then find erroneous memory accesses.
   // (There should be none, of course.)
-  sigc::slot<std::string, int, std::string>* psl2 = new sigc::slot<std::string, int, std::string>;
+  auto psl2 = new sigc::slot<std::string, int, std::string>;
   bar_group4* pbar4 = new bar_group4;
   book* pbook4 = new book("A Book");
   *psl2 = sigc::track_obj(Functor2(*pbar4, *pbook4), *pbar4, *pbook4);
@@ -148,13 +148,13 @@ int main(int argc, char* argv[])
   util->check_result(result_stream, "zero, Book title: A Book");
 
   delete pbook4; // auto-disconnect *psl2
-  pbook4 = 0;
+  pbook4 = nullptr;
   result_stream << (*psl2)(0, "Book title: ");
   util->check_result(result_stream, "");
   delete psl2;
-  psl2 = 0;
+  psl2 = nullptr;
   delete pbar4;
-  pbar4 = 0;
+  pbar4 = nullptr;
 
 
 //C++11 lambda expressions:
